Crate dialogical

source ·
literally rewriting it in rust because i got tired of trying to make modules work properly instead of being able to write actual code

  • &Cherry, 11/20/2023

Modules

Structs

Enums

Functions

Type Aliases

  • Represents a list of interactions, but with a HashMap so you don’t have to constantly filter through the list