pub type InteractionMap = HashMap<String, Interaction>;Expand description
Represents a list of interactions, but with a HashMap so you don’t have to constantly filter through the list
Aliased Type
pub struct InteractionMap { /* private fields */ }pub type InteractionMap = HashMap<String, Interaction>;Represents a list of interactions, but with a HashMap so you don’t have to constantly filter through the list
pub struct InteractionMap { /* private fields */ }